format_data: Format data for outcome

Description Usage

View source: R/format_data.R

Description

The predictors in this model will be total dose of sedation, time that sedation was administered, duration and time since previous apneic event, and (non-missing) patient demographics.

Usage

1
format_data(resp_data, durations, lower_trigger, upper_trigger)

awconway/capnopred documentation built on Dec. 15, 2021, 5:01 a.m.